Enum parity_wasm::elements::Error [−][src]
pub enum Error {
Show 31 variants
UnexpectedEof,
InvalidMagic,
UnsupportedVersion(u32),
InconsistentLength {
expected: usize,
actual: usize,
},
Other(&'static str),
HeapOther(String),
UnknownValueType(i8),
UnknownTableElementType(i8),
NonUtf8String,
UnknownExternalKind(u8),
UnknownInternalKind(u8),
UnknownOpcode(u8),
InvalidVarUint1(u8),
InvalidVarInt32,
InvalidVarInt64,
InvalidVarUint32,
InvalidVarUint64,
InconsistentMetadata,
InvalidSectionId(u8),
SectionsOutOfOrder,
DuplicatedSections(u8),
InvalidMemoryReference(u8),
InvalidTableReference(u8),
InvalidLimitsFlags(u8),
UnknownFunctionForm(u8),
InvalidVarInt7(u8),
InconsistentCode,
InvalidSegmentFlags(u32),
TooManyLocals,
DuplicatedNameSubsections(u8),
UnknownNameSubsectionType(u8),
}Expand description
Deserialization/serialization error
Variants
Unexpected end of input.
Invalid magic.
UnsupportedVersion(u32)Unsupported version.
Tuple Fields of UnsupportedVersion
0: u32Inconsistence between declared and actual length.
Fields of InconsistentLength
Other(&'static str)Other static error.
Tuple Fields of Other
0: &'static strHeapOther(String)Other allocated error.
Tuple Fields of HeapOther
0: StringUnknownValueType(i8)Invalid/unknown value type declaration.
Tuple Fields of UnknownValueType
0: i8UnknownTableElementType(i8)Invalid/unknown table element type declaration.
Tuple Fields of UnknownTableElementType
0: i8Non-utf8 string.
UnknownExternalKind(u8)Unknown external kind code.
Tuple Fields of UnknownExternalKind
0: u8UnknownInternalKind(u8)Unknown internal kind code.
Tuple Fields of UnknownInternalKind
0: u8UnknownOpcode(u8)Unknown opcode encountered.
Tuple Fields of UnknownOpcode
0: u8InvalidVarUint1(u8)Invalid VarUint1 value.
Tuple Fields of InvalidVarUint1
0: u8Invalid VarInt32 value.
Invalid VarInt64 value.
Invalid VarUint32 value.
Invalid VarUint64 value.
Inconsistent metadata.
InvalidSectionId(u8)Invalid section id.
Tuple Fields of InvalidSectionId
0: u8Sections are out of order.
DuplicatedSections(u8)Duplicated sections.
Tuple Fields of DuplicatedSections
0: u8InvalidMemoryReference(u8)Invalid memory reference (should be 0).
Tuple Fields of InvalidMemoryReference
0: u8InvalidTableReference(u8)Invalid table reference (should be 0).
Tuple Fields of InvalidTableReference
0: u8InvalidLimitsFlags(u8)Invalid value used for flags in limits type.
Tuple Fields of InvalidLimitsFlags
0: u8UnknownFunctionForm(u8)Unknown function form (should be 0x60).
Tuple Fields of UnknownFunctionForm
0: u8InvalidVarInt7(u8)Invalid varint7 (should be in -64..63 range).
Tuple Fields of InvalidVarInt7
0: u8Number of function body entries and signatures does not match.
InvalidSegmentFlags(u32)Only flags 0, 1, and 2 are accepted on segments.
Tuple Fields of InvalidSegmentFlags
0: u32Sum of counts of locals is greater than 2^32.
DuplicatedNameSubsections(u8)Duplicated name subsections.
Tuple Fields of DuplicatedNameSubsections
0: u8UnknownNameSubsectionType(u8)Unknown name subsection type.
Tuple Fields of UnknownNameSubsectionType
0: u8Trait Implementations