Enum parity_wasm::elements::Section [−][src]
pub enum Section {
Show 16 variants
Unparsed {
id: u8,
payload: Vec<u8>,
},
Custom(CustomSection),
Type(TypeSection),
Import(ImportSection),
Function(FunctionSection),
Table(TableSection),
Memory(MemorySection),
Global(GlobalSection),
Export(ExportSection),
Start(u32),
Element(ElementSection),
DataCount(u32),
Code(CodeSection),
Data(DataSection),
Name(NameSection),
Reloc(RelocSection),
}Expand description
Section in the WebAssembly module.
Variants
Section is unparsed.
Fields of Unparsed
Custom(CustomSection)Custom section (id=0).
Tuple Fields of Custom
Type(TypeSection)Types section.
Tuple Fields of Type
0: TypeSectionImport(ImportSection)Import section.
Tuple Fields of Import
Function(FunctionSection)Function signatures section.
Tuple Fields of Function
Table(TableSection)Table definition section.
Tuple Fields of Table
0: TableSectionMemory(MemorySection)Memory definition section.
Tuple Fields of Memory
Global(GlobalSection)Global entries section.
Tuple Fields of Global
Export(ExportSection)Export definitions.
Tuple Fields of Export
Start(u32)Entry reference of the module.
Tuple Fields of Start
0: u32Element(ElementSection)Elements section.
Tuple Fields of Element
DataCount(u32)Number of passive data entries in the data section
Tuple Fields of DataCount
0: u32Code(CodeSection)Function bodies section.
Tuple Fields of Code
0: CodeSectionData(DataSection)Data definition section.
Tuple Fields of Data
0: DataSectionName(NameSection)Name section.
Note that initially it is not parsed until parse_names is called explicitly.
Tuple Fields of Name
0: NameSectionReloc(RelocSection)Relocation section.
Note that initially it is not parsed until parse_reloc is called explicitly.
Also note that currently there are serialization (but not de-serialization)
issues with this section (#198).
Tuple Fields of Reloc
0: RelocSectionTrait Implementations